@@ -4,9 +4,11 @@ import re
 import sys
 
 from pathlib import Path
-from typing import NoReturn
+from typing import NoReturn, List, Tuple
 
-PLAN_COMPONENT_REGEX = "\d: ([\w+\s?]+)\n"
+PLAN_COMPONENT_REGEX = "\d: ([\w+\s?-]+)\n"
+VALID_PLAN_FOUND_PATTERN = "ff: found legal plan as follows"
+NO_SOLUTION_FOUND_PATTERN = "problem proven unsolvable."
 
 
 class MetricFFParser:
@@ -26,6 +28,22 @@ class MetricFFParser:
         with open(input_path, "rt") as interm_plan_file:
             return interm_plan_file.read()
 
+    def _parse_plan_content(self, planner_output) -> List[str]:
+        """Parse the content of the file and export the action sequence.
+
+        :param planner_output: the file content with the possible action sequence.
+        :return: the action sequence.
+        """
+        matches = re.finditer(PLAN_COMPONENT_REGEX, planner_output, re.MULTILINE)
+        plan_seq = []
+        for match in matches:
+            action_sequence = match.group(1)
+            self.logger.debug(f"action sequence - {action_sequence}")
+            plan_seq.append(f"({action_sequence.lower().strip()})\n")
+
+        if len(plan_seq) == 0:
+            return []
+
     def parse_plan(self, input_path: Path, output_path: Path) -> NoReturn:
         """Parse the output file and exports a plan if exists.
 
@@ -33,27 +51,31 @@ class MetricFFParser:
         :param output_path: the path to the output plan file.
         """
         planner_output = self._open_plan_file(input_path)
-        matches = re.finditer(PLAN_COMPONENT_REGEX, planner_output, re.MULTILINE)
-        plan_seq = []
-        for match in matches:
-            action_sequence = match.group(1)
-            self.logger.debug(f"action sequence - {action_sequence}")
-            plan_seq.append(f"({action_sequence.lower().strip()})\n")
-        if len(plan_seq) == 0:
+        action_sequence = self._parse_plan_content(planner_output)
+        if len(action_sequence) == 0:
             return
 
         with open(output_path, "wt") as output_file:
-            output_file.writelines(plan_seq)
+            output_file.writelines(action_sequence)
 
-    def is_valid_plan_file(self, input_path: Path) -> bool:
-        """
+    def get_solving_status(self, input_path: Path) -> Tuple[str, List[str]]:
+        """Validates if the plan file contains a valid plan.
 
-        :param input_path:
-        :return:
+        :param input_path: the path to the input file.
+        :return: "ok" if a plan exists, "timeout" if the solver timed out or "no-solution"
+            if there is no solution for the problem as well as the action sequence.
         """
         file_content = self._open_plan_file(input_path)
-        matches = re.findall(PLAN_COMPONENT_REGEX, file_content, re.MULTILINE)
-        return len(matches) > 0
+        plan_found = re.search(PLAN_COMPONENT_REGEX, file_content, re.MULTILINE)
+        if plan_found is not None:
+            action_sequence = self._parse_plan_content(file_content)
+            return "ok", action_sequence
+
+        no_solution = re.search(NO_SOLUTION_FOUND_PATTERN, file_content, re.MULTILINE)
+        if no_solution is not None:
+            return "no-solution", []
+
+        return "timeout", []
 
 
 if __name__ == '__main__':
